API documentation — abexp 0.0.1 documentation

# API documentation

## Architecture

- `abexp.core` contains the most relevant modules to run A/B test experiments.

  > - `abexp.core.design`

  > - `abexp.core.planning`

  > - `abexp.core.allocation`

  > - `abexp.core.analysis_frequentist`

  > - `abexp.core.analysis_bayesian`

- `abexp.statistics` provides statistical utils used in the modules above.

  > - `abexp.statistics.stats_metrics`

  > - `abexp.statistics.stats_tests`

- `abexp.visualization` contains modules to display A/B test results.

  > - `abexp.visualization.analysis_plots`

## API

Please visit the full API list for details.